package com.benyun.service.impl;


import cn.hutool.core.util.StrUtil;
import com.benyun.boot.core.vo.Result;
import com.benyun.dao.ApplyDao;
import com.benyun.dao.EventDao;
import com.benyun.entity.Apply;
import com.benyun.entity.Event;
import com.benyun.service.ApplyService;
import com.benyun.vo.ApplyEventVo;
import lombok.RequiredArgsConstructor;
import org.beetl.sql.core.engine.PageQuery;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.List;
import java.util.UUID;

/**
 * 应用表(Apply)表服务实现
 *
 * @author makejava
 * create on 2023-03-17 10:03:25
 */
@Service
@RequiredArgsConstructor(onConstructor_ = {@Autowired})
public class ApplyServiceImpl implements ApplyService {

    private final ApplyDao applyDao;
    private final EventDao eventDao;

    @Override
    public Apply queryById(String id) {
        return applyDao.single(id);
    }

    @Override
    public List<Apply> queryAll() {
        return applyDao.all();
    }

    @Override
    public List<Apply> queryList(String applyName) {
        return applyDao.createLambdaQuery().andLike(Apply::getApplyName, "%" + (StrUtil.isNotBlank(applyName)? applyName: "") + "%").select();
    }

    @Override
    public void copyFrom(String target, String from) {
        List<Event> select = eventDao.createLambdaQuery()
                .andEq(Event::getApplyId, from)
                .select();

        ArrayList<Event> list = new ArrayList<>();
        for (Event event : select) {
            event.setId(target+"@"+event.getEventCode());
            event.setApplyId(target);
            list.add(event);
        }
        eventDao.insertBatch(list);

    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void insert(Apply apply) {
        applyDao.insert(apply);
    }

    /**
     * 根据主键更新记录
     *
     * @param apply 待更新的记录.包含主键在内，如果其他列的值为空则不更新
     * @return 成功返回true，失败返回false
     */
    @Override
    public boolean updateById(Apply apply) {
        return applyDao.updateTemplateById(apply) > 0;
    }

    /**
     * 根据主键删除记录
     *
     * @param id 主键
     * @return 成功返回true，反之返回false
     */
    @Override
    public boolean deleteById(String id) {
        return applyDao.deleteById(id) > 0;
    }

    /**
     * 分页查询
     *
     * @param pageQuery 封装分页条件的分页对象
     * @return pageQuery 作为一个引用，将查询结果封装进去
     */
    @Override
    public Result<List<Apply>> queryByPage(PageQuery<Apply> pageQuery) {
        applyDao.queryByPage(pageQuery);
        Result<List<Apply>> result = Result.success();
        result.setData(pageQuery.getList());
        result.setCount((int) pageQuery.getTotalRow());
        return result;
    }

    @Override
    public ApplyEventVo queryApplyEventByUUId(String uuid) {
        ApplyEventVo applyEventVo = applyDao.queryApplyEventByUUId(uuid);
        return applyEventVo;
    }
}
