package com.benyun.service.impl;


import com.benyun.dao.EventDao;
import com.benyun.entity.Event;
import com.benyun.service.EventService;
import com.benyun.vo.EventPageVo;
import lombok.RequiredArgsConstructor;
import org.beetl.sql.core.engine.PageQuery;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.Date;
import java.util.List;

/**
 * 事件信息表(Event)表服务实现
 *
 * @author makejava
 * create on 2023-03-21 09:20:28
 */
@Service
@RequiredArgsConstructor(onConstructor_ = {@Autowired})
public class EventServiceImpl implements EventService {

    private final EventDao eventDao;

    @Override
    public Event queryById(String id, String applyId) {
        return eventDao.queryById(id, applyId);
    }

    @Override
    public List<Event> queryAll() {
        return eventDao.all();
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void insert(Event event) {
        event.setId(event.getApplyId() + "@" + event.getEventCode());
        event.setCreatedTime(new Date());
        eventDao.insert(event, true);
    }

    /**
     * 根据主键更新记录
     *
     * @param event 待更新的记录.包含主键在内，如果其他列的值为空则不更新
     * @return 成功返回true，失败返回false
     */
    @Override
    public boolean updateById(Event event) {
        return eventDao.updateTemplateById(event) > 0;
    }

    /**
     * 根据主键更新记录
     *
     * @param event 待更新的记录.包含主键在内，如果其他列的值为空则不更新
     * @return 成功返回true，失败返回false
     */
    @Override
    public boolean updateById2(Event event) {
        String eventId = event.getId();
        event.setId(event.getApplyId() + "@" + event.getEventName());
        return eventDao.updateById2(event, eventId) > 0;
    }

    /**
     * 根据主键删除记录
     *
     * @param id 主键
     * @return 成功返回true，反之返回false
     */
    @Override
    public boolean deleteById(String id) {
        return eventDao.deleteById(id) > 0;
    }

    /**
     * 根据主键删除记录
     *
     * @param id 主键
     * @param applyId 应用uuid 主键
     * @return 成功返回true，反之返回false
     */
    @Override
    public boolean deleteById(String id, String applyId) {
        return eventDao.deleteByIdAndApplyId(id, applyId) > 0;
    }

    /**
     * 分页查询
     *
     * @param pageQuery 封装分页条件的分页对象
     * @return pageQuery 作为一个引用，将查询结果封装进去
     */
    @Override
    public EventPageVo queryByPage(PageQuery<Event> pageQuery) {
        eventDao.queryByPage(pageQuery);
        EventPageVo eventPageVo = new EventPageVo();
        eventPageVo.setTotalRow((int) pageQuery.getTotalRow());
        eventPageVo.setEventList(pageQuery.getList());
        return eventPageVo;
    }
}
